@@ -285,9 +285,6 @@
    DRI_CONF_OPT_I(override_vram_size, -1, -1, 2147483647, \
                   "Override the VRAM size advertised to the application in MiB (-1 = default)")
 
-#define DRI_CONF_FORCE_GL_NAMES_REUSE() \
-   DRI_CONF_OPT_I(reuse_gl_names, -1, -1, 1, "GL names reuse: 1=enable, 0=disable, -1=default")
-
 #define DRI_CONF_FORCE_GL_MAP_BUFFER_SYNCHRONIZED(def) \
    DRI_CONF_OPT_B(force_gl_map_buffer_synchronized, def, "Override GL_MAP_UNSYNCHRONIZED_BIT.")
 
@@ -327,6 +324,10 @@
    DRI_CONF_OPT_B(vk_dont_care_as_load, def, \
                   "Treat VK_ATTACHMENT_LOAD_OP_DONT_CARE as LOAD_OP_LOAD, workaround on tiler GPUs for games that confuse these two load ops")
 
+#define DRI_CONF_VK_LOWER_TERMINATE_TO_DISCARD(def) \
+   DRI_CONF_OPT_B(vk_lower_terminate_to_discard, def, \
+                  "Lower terminate to discard (which is implicitly demote)")
+
 #define DRI_CONF_LIMIT_TRIG_INPUT_RANGE(def) \
    DRI_CONF_OPT_B(limit_trig_input_range, def, \
                   "Limit trig input range to [-2p : 2p] to improve sin/cos calculation precision on Intel")
@@ -523,6 +524,10 @@
    DRI_CONF_OPT_B(allow_multisampled_copyteximage, def, \
                   "Allow CopyTexSubImage and other to copy sampled framebuffer")
 
+#define DRI_CONF_VERTEX_PROGRAM_DEFAULT_OUT(def) \
+   DRI_CONF_OPT_B(vertex_program_default_out, def, \
+                  "Initialize outputs of vertex program to a default value vec4(0, 0, 0, 1)")
+
 #define DRI_CONF_CUSTOM_BORDER_COLORS_WITHOUT_FORMAT(def) \
    DRI_CONF_OPT_B(custom_border_colors_without_format, def, \
                   "Enable custom border colors without format")
@@ -546,56 +551,6 @@
 #define DRI_CONF_DRI_DRIVER() \
    DRI_CONF_OPT_S_NODEF(dri_driver, "Override the DRI driver to load")
 
-/**
- * \brief Gallium-Nine specific configuration options
- */
-
-#define DRI_CONF_SECTION_NINE DRI_CONF_SECTION("Gallium Nine")
-
-#define DRI_CONF_NINE_THROTTLE(def) \
-   DRI_CONF_OPT_I(throttle_value, def, 0, 0, \
-                  "Define the throttling value. -1 for no throttling, -2 for default (usually 2), 0 for glfinish behaviour")
-
-#define DRI_CONF_NINE_THREADSUBMIT(def) \
-   DRI_CONF_OPT_B(thread_submit, def, \
-                  "Use an additional thread to submit buffers.")
-
-#define DRI_CONF_NINE_OVERRIDEVENDOR(def) \
-   DRI_CONF_OPT_I(override_vendorid, def, 0, 0, \
-                  "Define the vendor_id to report. This allows faking another hardware vendor.")
-
-#define DRI_CONF_NINE_ALLOWDISCARDDELAYEDRELEASE(def) \
-   DRI_CONF_OPT_B(discard_delayed_release, def, \
-                  "Whether to allow the display server to release buffers with a delay when using d3d's presentation mode DISCARD. Default to true. Set to false if suffering from lag (thread_submit=true can also help in this situation).")
-
-#define DRI_CONF_NINE_TEARFREEDISCARD(def) \
-   DRI_CONF_OPT_B(tearfree_discard, def, \
-                  "Whether to make d3d's presentation mode DISCARD (games usually use that mode) Tear Free. If rendering above screen refresh, some frames will get skipped. true by default.")
-
-#define DRI_CONF_NINE_CSMT(def) \
-   DRI_CONF_OPT_I(csmt_force, def, 0, 0, \
-                  "If set to 1, force gallium nine CSMT. If set to 0, disable it. By default (-1) CSMT is enabled on known thread-safe drivers.")
-
-#define DRI_CONF_NINE_DYNAMICTEXTUREWORKAROUND(def) \
-   DRI_CONF_OPT_B(dynamic_texture_workaround, def, \
-                  "If set to true, use a ram intermediate buffer for dynamic textures. Increases ram usage, which can cause out of memory issues, but can fix glitches for some games.")
-
-#define DRI_CONF_NINE_SHADERINLINECONSTANTS(def) \
-   DRI_CONF_OPT_B(shader_inline_constants, def, \
-                  "If set to true, recompile shaders with integer or boolean constants when the values are known. Can cause stutter, but can increase slightly performance.")
-
-#define DRI_CONF_NINE_SHMEM_LIMIT() \
-   DRI_CONF_OPT_I(texture_memory_limit, 128, 0, 0, \
-                  "In MB the limit of virtual memory used for textures until shmem files are unmapped (default 128MB, 32bits only). If negative disables shmem. Set to a low amount to reduce virtual memory usage, but can incur a small perf hit if too low.")
-
-#define DRI_CONF_NINE_FORCESWRENDERINGONCPU(def) \
-   DRI_CONF_OPT_B(force_sw_rendering_on_cpu, def, \
-                  "If set to false, emulates software rendering on the requested device, else uses a software renderer.")
-
-#define DRI_CONF_NINE_FORCEFEATURESEMULATION(def) \
-   DRI_CONF_OPT_B(force_features_emulation, def, \
-                  "If set to true, force emulation of d3d9 features when possible instead of using native hw support.")
-
 #define DRI_CONF_V3D_NONMSAA_TEXTURE_SIZE_LIMIT(def) \
    DRI_CONF_OPT_B(v3d_nonmsaa_texture_size_limit, def, \
                   "Report the non-MSAA-only texture size limit")
@@ -644,6 +599,10 @@
    DRI_CONF_OPT_B(disable_conservative_lrz, def, \
                   "Disable conservative LRZ")
 
+#define DRI_CONF_DISABLE_EXPLICIT_SYNC_HEURISTIC(def) \
+   DRI_CONF_OPT_B(disable_explicit_sync_heuristic, def, \
+                  "Disable Explicit-sync heuristic")
+
 /**
  * \brief panfrost specific configuration options
  */
@@ -656,6 +615,14 @@
    DRI_CONF_OPT_U64(pan_fragment_core_mask, def, 0, UINT64_MAX, \
                     "Bitmask of shader cores that may be used for fragment jobs. If unset, defaults to scheduling across all available cores.")
 
+#define DRI_CONF_PAN_ENABLE_VERTEX_PIPELINE_STORES_ATOMICS(def) \
+   DRI_CONF_OPT_B(pan_enable_vertex_pipeline_stores_atomics, def, \
+                  "Enable vertexPipelineStoresAndAtomics on v13+ (This cannot work on older generation because of speculative behaviors around vertices)")
+
+#define DRI_CONF_PAN_FORCE_ENABLE_SHADER_ATOMICS(def) \
+   DRI_CONF_OPT_B(pan_force_enable_shader_atomics, def, \
+                  "Enable fragmentStoresAndAtomics and vertexPipelineStoresAndAtomics on any architecture. (This may not work reliably and is for debug purposes only!)")
+
 /**
  * \brief Turnip specific configuration options
  */
@@ -676,6 +643,10 @@
    DRI_CONF_OPT_B(tu_use_tex_coord_round_nearest_even_mode, def, \
                   "Use D3D-compliant round-to-nearest-even mode for texture coordinates")
 
+#define DRI_CONF_TU_IGNORE_FRAG_DEPTH_DIRECTION(def) \
+   DRI_CONF_OPT_B(tu_ignore_frag_depth_direction, def, \
+                  "Ignore direction specified for gl_FragDepth output")
+
 /**
  * \brief Honeykrisp specific configuration options
  */
@@ -684,10 +655,6 @@
    DRI_CONF_OPT_B(hk_disable_border_emulation, def, \
                   "Disable custom border colour emulation")
 
-#define DRI_CONF_HK_DISABLE_RGBA4_BORDER_COLOR_WORKAROUND(def) \
-   DRI_CONF_OPT_B(hk_disable_rgba4_border_color_workaround, def, \
-                  "Use hardware opaque_black, breaking certain RGBA4 formats")
-
 #define DRI_CONF_HK_FAKE_MINMAX(def) \
    DRI_CONF_OPT_B(hk_fake_minmax, def, \
                   "Fake support for min/max filtering")
@@ -753,11 +720,7 @@
 
 #define DRI_CONF_RADV_DISABLE_DCC_STORES(def) \
    DRI_CONF_OPT_B(radv_disable_dcc_stores, def, \
-                  "Disable DCC for color storage images")
-
-#define DRI_CONF_RADV_LOWER_TERMINATE_TO_DISCARD(def) \
-   DRI_CONF_OPT_B(radv_lower_terminate_to_discard, def, \
-                  "Lower terminate to discard (which is implicitly demote)")
+                  "Disable DCC for color storage images on GFX10-GFX11.5")
 
 #define DRI_CONF_RADV_DISABLE_ANISO_SINGLE_LEVEL(def) \
   DRI_CONF_OPT_B(radv_disable_aniso_single_level, def, \
@@ -800,10 +763,6 @@
    DRI_CONF_OPT_B(radv_rt_wave64, def, \
                   "Force wave64 in RT shaders")
 
-#define DRI_CONF_RADV_DISABLE_DEDICATED_SPARSE_QUEUE(def) \
-   DRI_CONF_OPT_B(radv_disable_dedicated_sparse_queue, def, \
-                  "Disables the dedicated sparse queue. This replaces radv_legacy_sparse_binding as a compatible drirc workaround for games that might not expect a separate SPARSE queue")
-
 /**
  * Overrides for forcing re-compilation of pipelines when RADV_BUILD_ID_OVERRIDE is enabled.
  * These need to be bumped every time a compiler bugfix is backported (up to 8 shader
@@ -837,6 +796,14 @@
    DRI_CONF_OPT_B(radv_enable_float16_gfx8, def, \
                   "Expose float16 on GFX8, where it's supported but usually not beneficial.")
 
+#define DRI_CONF_RADV_DISABLE_HIZ_HIS_GFX12(def) \
+   DRI_CONF_OPT_B(radv_disable_hiz_his_gfx12, def, \
+                  "Disable HiZ/HiS on GFX12 (RDNA4) to workaround a hw bug that causes random GPU hangs")
+
+#define DRI_CONF_RADV_COOPERATIVE_MATRIX2_NV(def) \
+   DRI_CONF_OPT_B(radv_cooperative_matrix2_nv, def, \
+                  "Expose VK_NV_cooperative_matrix2 on supported hardware.")
+
 /**
  * \brief ANV specific configuration options
  */
@@ -853,6 +820,10 @@
    DRI_CONF_OPT_B(anv_assume_full_subgroups_with_shared_memory, def, \
                   "Allow assuming full subgroups requirement for shaders using shared memory even when it's not specified explicitly")
 
+#define DRI_CONF_ANV_EMULATE_READ_WITHOUT_FORMAT(def) \
+   DRI_CONF_OPT_B(anv_emulate_read_without_format, def, \
+                  "Emulate shaderStorageImageReadWithoutFormat with shader conversions")
+
 #define DRI_CONF_ANV_SAMPLE_MASK_OUT_OPENGL_BEHAVIOUR(def) \
    DRI_CONF_OPT_B(anv_sample_mask_out_opengl_behaviour, def, \
                   "Ignore sample mask out when having single sampled target")
@@ -861,15 +832,6 @@
    DRI_CONF_OPT_B(anv_force_filter_addr_rounding, def, \
                   "Force min/mag filter address rounding to be enabled even for NEAREST sampling")
 
-#define DRI_CONF_ANV_MESH_CONV_PRIM_ATTRS_TO_VERT_ATTRS(def) \
-   DRI_CONF_OPT_E(anv_mesh_conv_prim_attrs_to_vert_attrs, def, -2, 2, \
-                  "Apply workaround for gfx12.5 per-prim attribute corruption HW bug", \
-                  DRI_CONF_ENUM(-2, "enable attribute conversion and vertex duplication ONLY if needed") \
-                  DRI_CONF_ENUM(-1, "enable attribute conversion ONLY if needed") \
-                  DRI_CONF_ENUM(0,  "disable workaround") \
-                  DRI_CONF_ENUM(1,  "enable attribute conversion ALWAYS") \
-                  DRI_CONF_ENUM(2,  "enable attribute conversion and vertex duplication ALWAYS") )
-
 #define DRI_CONF_ANV_FP64_WORKAROUND_ENABLED(def) \
    DRI_CONF_OPT_B(fp64_workaround_enabled, def, \
                   "Use softpf64 when the shader uses float64, but the device doesn't support that type")
@@ -920,6 +882,10 @@
    DRI_CONF_OPT_B(anv_vf_component_packing, def, \
                   "Vertex fetching component packing")
 
+#define DRI_CONF_ANV_LARGE_WORKGROUP_NON_COHERENT_IMAGE_WORKAROUND(def) \
+   DRI_CONF_OPT_B(anv_large_workgroup_non_coherent_image_workaround, def, \
+                  "Fixup image coherency qualifier for certain shaders.")
+
 /**
  * \brief HASVK specific configuration options
  */
